@@ -29,8 +29,8 @@ class TaskResult:
         self.stack_trace = stack_trace
 
     @staticmethod
-    def create_from_request_entity(self, entity):
-        result, error_message, stack = None
+    def create_from_request_entity(entity):
+        result, error, trace = None, None, None
         if 'Result' in entity:
             result = entity['Result']
         if 'Error' in entity:
